<?php

    class FileCache
    {
        protected $dir;

        /**
         * @var array Froups for which directories have already been created
         */
        private $known_groups = array();

        /**
         * @var array In-memory Cache
         */
        private $cache = array();

        /**
         * @var array Non-persistent groups
         */
        protected $np_groups  = array();

        /**
         * @static
         * @param string $dir
         * @return FileCache
         */
        public static function& instance($dir = '/tmp')
        {
            static $self = null;

            if (true == is_null($self)) {
                $self = new FileCache($dir);
            }

            return $self;
        }

        /**
         * @param string $path
         * @return FileCache
         */
        public function __construct($path = '/tmp')
        {
            if ('' == $path) {
                $path = '/tmp';
            }

            $this->dir = $path;
        }

        public function add($key, &$data, $group)
        {
            if (true == empty($group)) {
                $group = 'default';
            }

            if (false !== $this->get($key, $group)) {
                return false;
            }

            return $this->set($key, $data, $group);
        }

        public function delete($key, $group)
        {
            if (true == empty($group)) {
                $group = 'default';
            }

            unset($this->cache[$group][$key]);

            if (false === in_array($group, $this->np_groups)) {
                $fname = $this->keyToPath($key, $group);
                return @unlink($fname);
            }

            return true;
        }

        protected function remove_dir($dir, $self)
        {
            $dh = @opendir($dir);
            if (false === $dh) {
                return;
            }

            while (false !== ($obj = readdir($dh))) {
                if ('.' == $obj || '..' == $obj) {
                    continue;
                }

                if (false == @unlink($dir . '/' . $obj)) {
                    $this->remove_dir($dir . '/' . $obj, true);
                }
            }

            closedir($dh);
            if (true == $self) {
                @rmdir($dir);
            }
        }

        public function flush()
        {
            $this->remove_dir($this->dir, false);
            $this->cache = array();
            $this->known_groups = array();
            return true;
        }

        public function set($key, &$data, $group)
        {
            if (true == empty($group)) {
                $group = 'default';
            }

            $this->cache[$group][$key] = $data;
            if (false === in_array($group, $this->np_groups)) {
                $fname = $this->keyToPath($key, $group);
                $f     = @fopen($fname, 'wb');
                if (true == is_resource($f)) {
                    fputs($f, serialize($data));
                    fclose($f);
                    @chmod($fname, 0666);
                    return true;
                }
            }

            return true;
        }

        public function get($key, $group, $ttl = 3600)
        {
            if (true == empty($group)) {
                $group = 'default';
            }

            if (true == isset($this->cache[$group], $this->cache[$group][$key])) {
                return $this->cache[$group][$key];
            }

            if (false === in_array($group, $this->np_groups)) {
                $fname = $this->keyToPath($key, $group);
                $files = glob($fname);
                if (false === $files || true == empty($files) || false == isset($files[0])) {
                    return false;
                }

                if (true == is_readable($files[0])) {
                    $result = $files[0];
                    if (filemtime($result) > time() - $ttl) {
                        settype($result, 'string');
                        $this->cache[$group][$key] = unserialize(@file_get_contents($result));
                        return $this->cache[$group][$key];
                    }
                }

                @unlink($files[0]);
            }

            return false;
        }

        public function replace($key, &$data, $group)
        {
            if (true == empty($group)) {
                $group = 'default';
            }

            if (false === $this->get($key, $group)) {
                return false;
            }

            return $this->set($key, $data, $group);
        }

        public function addNonPersistentGroups($groups)
        {
            if (false == is_array($groups)) {
                $groups = array($groups);
            }

            $this->np_groups = array_merge(
                $this->np_groups,
                $groups
            );
        }

        public function clearNonPersistentGroups()
        {
            $this->np_groups = array();
        }

        protected function keyToPath($key, $group)
        {
            if (false == isset($this->known_groups[$group])) {
                $dir = $this->dir . '/' . urlencode($group);
                if (false == file_exists($dir)) {
                    @mkdir($dir);
                    @chmod($this->dir . '/' . urlencode($group), 0777);
                }

                $this->known_groups[$group] = true;
            }

            return $this->dir . '/' . urlencode($group) . '/' . urlencode($key) . '.cache';
        }
    }
?>